//------------------------------------------------------------------//
// Title:         01           //
// File:      bk01r_drv.h                                           //
// EDA Tool:  CodeMaster-96                                         //
// Revision:  1.0                                                   //
// Rev.Date:  20/02/2017                                            //
// Rev.Date:  24/04/2017                                            //
// Rev.Date:  08/07/2017                                            //
// Rev.Date:  12/07/2017                                            //
// Rev.Date:  31/07/2017                                            //
// Rev.Date:  21/08/2017                                            //
// Rev.Date:  26/09/2017                                            //
// Rev.Note:                                                        //
// Author(s):  ..                                          //
//------------------------------------------------------------------//
// Note:     !!!!!                          //
//------------------------------------------------------------------//
//   
#ifndef BK01R_DRIVER_H
#define BK01R_DRIVER_H

//   (/)
#define PK_A        0x00    //  
#define PK_B        0x80    //  

//    (/)
#define NOM_PDEV    0x00    //  
#define RSV_PDEV    0x80    //  

//   TEST
#define LED_OFF     0x00    //  
#define LED_ON      0x80    //  

//        04
#define RxD_OFF     0x00    //      
#define A_RxD_ON    0x01    //     
#define B_RxD_ON    0x02    //     

// 
#define TIMER_DELAY  1      //   .
#define dXTAL        24000  //    18747  

//   
#define MKO_DRV_ON   0x00   //  /    /
#define MKO_DRV_OFF  0xFF   //  /    /

//         (SPI)
#define LINK_OK            0x00   //    : OK
#define LINK_ERR           0xFF   //    : ERROR
#define LINK_DIAG_ERR      0x20   //   DIAG
#define LINK_NOP_ERR       0x40   //   NOP
#define LINK_ID_ERR        0x80   //   READ-WRITE-READ  -
#define LINK_INIT_ADDR     0x50   //   -  
#define LINK_INIT_DATA     0xAA   //    -  

//         (LNK_STAT_XX bits):
// [0]- ()  
// [1]-  - ( /)
// [2]-  - ( /)
// [3]-  - ( /)
// [4]-  - ( /)
// [5]-  DIAG
// [6]-  NOP
// [7]-  READ-WRITE-READ  -

#define LINK_ERR_T0      0x01   //    ()
#define LINK_ERR_T1      0x02   //   - (./,.CRC)
#define LINK_ERR_T2      0x04   //   - ( /,.CRC)
#define LINK_ERR_T3      0x08   //   - ( /,.CRC)
#define LINK_ERR_T4      0x10   //   - ( /,.CRC)

// Reference         SPI
//  - !  -().
typedef struct {
   unsigned char LNK_STAT_n0;   //    -0
   unsigned char LNK_STAT_n1;   //    -1
   unsigned char LNK_STAT_n2;   //    -2
   unsigned char LNK_STAT_n3;   //    -3
   unsigned char LNK_STAT_n4;   //    -4
   unsigned char LNK_STAT_r0;   //    -0
   unsigned char LNK_STAT_r1;   //    -1
   unsigned char LNK_STAT_r2;   //    -2
   unsigned char LNK_STAT_r3;   //    -3
   unsigned char LNK_STAT_r4;   //    -4
   } link_status;

//     ()
#define NOM_RAM        0x0      //  
#define RSV_RAM        0x80     //  
#define MEM_SIZE       0x08     //      4
#define PAGE_SIZE      0x1000   //    (4)
#define VALID_PAGE     0x0      //   
#define INVALID_PAGE   0xFF     //   
#define PREV_PAGE      0x0      //   
#define NEXT_PAGE      0xFF     //   
#define RUN_ZERO       0x0      // " "
#define RUN_ONE        0xFF     // " "
#define MEM_CTRL_OK    0x0      //      
#define MEM_CTRL_ERR   0xFF     //      

//   
//#define CRC_BLK_LEN     0x400    //       (DEBUG=1024 )
#define CRC_BLK_LEN     0xFFF   //      
#define CRC_OK          0x0     //    /   
#define CRC_ERROR       0xFF    //    /    
#define CRC_INIT        0xFFFF  //     CRC-16-CCITT
#define CRC_XOROUT      0x0000  //  XorOut   CRC-16-CCITT

//==================================================================//
//                                //
//==================================================================//
//   
unsigned char sys_get_pk_number();

//     
unsigned char sys_get_clk_status();

//     3.3
unsigned char sys_get_pwr_status();

//     18747
void sys_mc_clk_control();

//    
void sys_wdt_restart();

//   TEST
void sys_led_control(
    unsigned char led_ctrl      //  :0=./1=.
    );

//------------------------------------------------------------------//
//                      -1                        //
//------------------------------------------------------------------//
//      -1
void sys_set_timer_1(
   unsigned int tdelay   //   .
   );

//    -1
unsigned int sys_get_timer_1();

//      
unsigned char sys_get_ovf_timer_1();

//------------------------------------------------------------------//
//                                       //
//------------------------------------------------------------------//
//        04
void sys_uart_select(
   unsigned char rxd_control    //  
   );

//   
void sys_mko_drv_control(
   unsigned char mko_drv_ctrl   //   
   );

//      (SPI)
unsigned char sys_init_link_channel(
   unsigned char pk_num,       //  : 0x0=/0x80=
   unsigned char pdev_num,     //   
   PMLC_CMD_LIST *cmd_ptr,     //     -
   unsigned char *link_ptr     //       
   );

//------------------------------------------------------------------//
//                                                     //
//------------------------------------------------------------------//
//     
//  8 ()  ()  
void sys_rom_page_select();

//**************************************************************************//
//                    .                          //
//   CRC-16-CCITT     CRC-. //
//        0xFFF ,        //
//       CRC_SUM_TBL                    //
// Poly  : 0x1021  (x^16 + x^12 + x^5 + 1)                                  //
// Init  : 0xFFFF                                                           //
// Revert: false                                                            //
// XorOut: 0x0000                                                           //
// Check : 0x29B1 (ASCII  "123456789")                                  //
// MaxLen: 4095  (32767 ) -  , ,   //
//                                                       //
//**************************************************************************//
unsigned char sys_chk_prom_crc(
   unsigned short prog_len     //     ( )
   );

//------------------------------------------------------------------//
//                                      //
//------------------------------------------------------------------//
//     :              //
// 1)       512      //
// 2)                    //
// 3)      4 (PAGE_SIZE)  //
// 4) :1,...128                                    //
// 5)     MEM_SIZE.      //
//     MEM_SIZE = 0x08 (8*4=32)              //
// 6)   : 0,...127                 //
//------------------------------------------------------------------//
//     ,      //
//     ,   //
//   .                                        //
//     )))))                   //
//------------------------------------------------------------------//
//     (-1)
unsigned char sys_mem_chk_t1(
   unsigned char chk_value     //   (0x00, 0xFF, 0x55, 0xAA)
   );

//     (-2)
unsigned char sys_mem_chk_t2(
   unsigned char chk_type      //  :0x0=" "/0xFF=" "
   );

//      (4+2)
unsigned char sys_chk_mem_page(
   unsigned char mem_type,     //  : 0x0=/0x80=
   unsigned char pg_num        //    (0-127)
   );

//       ()  
void sys_set_mem_pg(
   unsigned char mem_type,     //  : 0x0=/0x80= 
   unsigned char pg_num        //    (0-127)
   );

//      
unsigned char sys_init_mem(
   unsigned char mem_type,        //  : 0x0=/0x80=
   unsigned char m_size,          //  -     4 
   unsigned char *start_mem_pg,   //     
   unsigned char *end_mem_pg,     //     
   unsigned char *cur_mem_pg      //    ()  
   );

//  /    
unsigned char  sys_next_mem_page(
   unsigned char mem_type,        //  : 0x0=/0x80=
   unsigned char dir,             //   :00=/0xFF=
   unsigned char *start_mem_pg,   //     
   unsigned char *end_mem_pg,     //     
   unsigned char *cur_mem_pg      //    ()  
   );

//      
unsigned char  sys_sel_mem_page(
   unsigned char mem_type,        //  : 0x0=/0x80=
   unsigned char new_pg,          //    
   unsigned char *start_mem_pg,   //     
   unsigned char *end_mem_pg,     //     
   unsigned char *cur_mem_pg      //    ()  
   );

//    
#endif
